/*
BSL-Scripter-3.1.0.0

==P432Target.cpp==

Copyright (c) 2008  2015 Texas Instruments Incorporated

All rights reserved not granted herein.

Limited License.

Texas Instruments Incorporated grants a world-wide, royalty-free,
non-exclusive license under copyrights and patents it now or
hereafter owns or controls to make, have made, use, import,
offer to sell and sell ("Utilize") this software subject to
the terms herein.  With respect to the foregoing patent license,
such license is granted  solely to the extent that any such patent
is necessary to Utilize the software alone.  The patent license
shall not apply to any combinations which include this software,
other than combinations with devices manufactured by or for TI
(TI Devices). No hardware patent is licensed hereunder.

Redistributions must preserve existing copyright notices and
reproduce this license (including the above copyright notice
and the disclaimer and (if applicable) source code license
limitations below) in the documentation and/or other materials
provided with the distribution

Redistribution and use in binary form, without modification,
are permitted provided that the following conditions are met:

*	No reverse engineering, decompilation, or disassembly of
this software is permitted with respect to any software
provided in binary form.

*	any redistribution and use are licensed by TI for use only
with TI Devices.

*	Nothing shall obligate TI to provide you with source code
for the software licensed and provided to you in object code.

If software source code is provided to you, modification and
redistribution of the source code are permitted provided that
the following conditions are met:

*	any redistribution and use of the source code, including any
resulting derivative works, are licensed by TI for use only
with TI Devices.

*	any redistribution and use of any object code compiled from
the source code and any resulting derivative works, are licensed
by TI for use only with TI Devices.

Neither the name of Texas Instruments Incorporated nor the names
of its suppliers may be used to endorse or promote products derived
from this software without specific prior written permission.

DISCLAIMER.

THIS SOFTWARE IS PROVIDED BY TI AND TIS LICENSORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL TI AND TIS LICENSORS
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Version:	Release:		Author:
3.0.1.0		08/07/2015		Fatmawati Santosa
3.1.0.0		10/26/2015		Fatmawati Santosa

*/

#include "stdafx.h"

/*******************************************************************************
*Class:       P432
*Function:    readParameters
*Description: setup the parameters for each BSL command in P432
*Parameters:  ActualCommandParams actualCommandParams:      get command
*Returns:     none
*******************************************************************************/
void P432Target::readParameters(ActualCommandParams actualCommandParams)
{
	switch (actualCommandParams.command)
	{
	case (Command::CHANGE_BAUD_RATE) :
		newBaudRate = std::stoi(actualCommandParams.paramsInput[1]);
		if (actualCommandParams.protocol == Protocol::UART)
		{
			switch (newBaudRate)
			{
			case 4800:  commandBaudRate = BAUD430_4800;  break;
			case 9600:  commandBaudRate = BAUD430_9600;  break;
			case 19200: commandBaudRate = BAUD430_19200; break;
			case 38400: commandBaudRate = BAUD430_38400; break;
			case 57600: commandBaudRate = BAUD430_57600; break;
			case 115200:commandBaudRate = BAUD430_115200; break;
			default:throw std::runtime_error("Wrong baud rate setting for UART communication..."); break;
			}
		}
		else
		{
			throw("CHANGE_BAUD_RATE command is not available for I2C and SPI protocol...");
		}
		break;

	case (Command::DELAY) :
		delayMs = std::stoi(actualCommandParams.paramsInput[1]);
		break;

	case (Command::CRC_CHECK_32) :
		actualCommandParams.paramsInput[1].erase(0, 2);
		address32 = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);

		actualCommandParams.paramsInput[2].erase(0, 2);
		length = std::stoul(actualCommandParams.paramsInput[2], nullptr, 16);

		if (length > 0xFFFF)
		{
			throw std::runtime_error("Length of the CRC check is out of range...");
		}

		break;

	case (Command::CRC_CHECK) :
		actualCommandParams.paramsInput[1].erase(0, 2);
		address = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);

		actualCommandParams.paramsInput[2].erase(0, 2);
		length = std::stoul(actualCommandParams.paramsInput[2], nullptr, 16);

		if (length > 0xFFFF)
		{
			throw std::runtime_error("Length of the CRC check is out of range...");
		}

		break;

	case (Command::ERASE_SEGMENT_32) :
		actualCommandParams.paramsInput[1].erase(0, 2);
		address = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);
		break;

	case (Command::ERASE_SEGMENT) :
		actualCommandParams.paramsInput[1].erase(0, 2);
		address = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);
		break;

	case (Command::SET_PC_32) :
		actualCommandParams.paramsInput[1].erase(0, 2);
		address32 = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);
		break;

	case (Command::SET_PC) :
		actualCommandParams.paramsInput[1].erase(0, 2);
		address = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);
		break;

	case (Command::RX_PASSWORD) :
		break;


	case (Command::RX_PASSWORD_32) :
		break;

	case (Command::TX_DATA_BLOCK_32) :
		offsetBytesRead = 0;

		actualCommandParams.paramsInput[1].erase(0, 2);
		address = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);

		actualCommandParams.paramsInput[2].erase(0, 2);
		length = std::stoul(actualCommandParams.paramsInput[2], nullptr, 16);

		totalBytesReceived = length;

		break;

	case (Command::TX_DATA_BLOCK) :
		offsetBytesRead = 0;

		actualCommandParams.paramsInput[1].erase(0, 2);
		address = std::stoul(actualCommandParams.paramsInput[1], nullptr, 16);

		actualCommandParams.paramsInput[2].erase(0, 2);
		length = std::stoul(actualCommandParams.paramsInput[2], nullptr, 16);

		totalBytesReceived = length;

		break;

	default:
		//no reading parameters
		break;
	}
}

/*******************************************************************************
*Class:       P432
*Function:    changeBaudRate
*Description: Execution of CHANGE_BAUD_RATE in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::changeBaudRate()
{
	DataBuffer commandBuffer;
	commandBuffer.data[0] = CHANGE_BAUD_RATE;
	commandBuffer.data[1] = commandBaudRate;
  	commandBuffer.size = 2;
  	numResponseBytes = -1;
   	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    crcCheck32
*Description: Execution of CRC_CHECK_32 in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::crcCheck32()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = CRC_CHECK_32;
	commandBuffer.data[1] = (uint8_t)(address32 & 0xFF);
	commandBuffer.data[2] = (uint8_t)((address32 >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((address32 >> 16) & 0xFF);
	commandBuffer.data[4] = (uint8_t)((address32 >> 24) & 0xFF);
	commandBuffer.data[5] = (uint8_t)(length & 0xFF);
	commandBuffer.data[6] = (uint8_t)((length >> 8) & 0xFF);
  	commandBuffer.size = 7;
  	numResponseBytes = 2;
 	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    crcCheck
*Description: Execution of CRC_CHECK in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::crcCheck()
{
	DataBuffer commandBuffer;
 	commandBuffer.data[0] = CRC_CHECK;
	commandBuffer.data[1] = (uint8_t)(address & 0xFF);
	commandBuffer.data[2] = (uint8_t)((address >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((address >> 16) & 0xFF);
	commandBuffer.data[4] = (uint8_t)(length & 0xFF);
	commandBuffer.data[5] = (uint8_t)((length >> 8) & 0xFF);
  	commandBuffer.size = 6;
 	numResponseBytes = 2;
 	return commandBuffer;
 }

/*******************************************************************************
*Class:       P432
*Function:    delay
*Description: Execution of DELAY in P432 family
*Parameters:  none
*Returns:     none
*******************************************************************************/
void P432Target::delay()
{
	std::this_thread::sleep_for(std::chrono::milliseconds(delayMs));
}

/*******************************************************************************
*Class:       P432
*Function:    eraseCheck
*Description: Execution of ERASE_CHECK in P432 family
*Parameters:  none
*Returns:     exception
*******************************************************************************/
DataBuffer P432Target::eraseCheck()
{
	throw std::runtime_error("ERASE_CHECK command is not available for P432 families...");
}

/*******************************************************************************
*Class:       P432
*Function:    eraseMainOrInfo
*Description: Execution of ERASE_MAIN_OR_INFO in P432 family
*Parameters:  none
*Returns:     exception
*******************************************************************************/
DataBuffer P432Target::eraseMainOrInfo()
{
	throw std::runtime_error("ERASE_MAIN_OR_INFO command is not available for P432 families...");
}

/*******************************************************************************
*Class:       P432
*Function:    eraseSegment32
*Description: Execution of ERASE_SEGMENT_32 in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::eraseSegment32()
{
	DataBuffer commandBuffer;
   	commandBuffer.data[0] = ERASE_SEGMENT_32;
	commandBuffer.data[1] = (uint8_t)(address & 0x000000FF);
	commandBuffer.data[2] = (uint8_t)((address >> 8) & 0x000000FF);
	commandBuffer.data[3] = (uint8_t)((address >> 16) & 0x000000FF);
	commandBuffer.data[4] = (uint8_t)((address >> 24) & 0x000000FF);
  	commandBuffer.size = 5;
   	numResponseBytes = 1;
   	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    eraseSegment
*Description: Execution of ERASE_SEGMENT in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::eraseSegment()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = ERASE_SEGMENT;
	commandBuffer.data[1] = (uint8_t)(address & 0xFF);
	commandBuffer.data[2] = (uint8_t)((address >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((address >> 16) & 0xFF);
  	commandBuffer.size = 4;
   	numResponseBytes = 1;
   	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    setPc32
*Description: Execution of SET_PC_32 in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::setPc32()
{
	DataBuffer commandBuffer;
   	commandBuffer.data[0] = SET_PC_32;
	commandBuffer.data[1] = (uint8_t)(address32 & 0xFF);
	commandBuffer.data[2] = (uint8_t)((address32 >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((address32 >> 16) & 0xFF);
	commandBuffer.data[4] = (uint8_t)((address32 >> 24) & 0xFF);
   	commandBuffer.size = 5;
  	numResponseBytes = 0;
  	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    setPc
*Description: Execution of SET_PC in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::setPc()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = SET_PC;
	commandBuffer.data[1] = (uint8_t)(address & 0xFF);
	commandBuffer.data[2] = (uint8_t)((address >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((address >> 16) & 0xFF);
  	commandBuffer.size = 4;
  	numResponseBytes = 0;
  	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    massErase
*Description: Execution of MASS_ERASE in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::massErase()
{
	DataBuffer commandBuffer;
 	commandBuffer.data[0] = MASS_ERASE;
  	commandBuffer.size = 1;
  	numResponseBytes = 1;
  	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    rebootReset
*Description: Execution of REBOOT_RESET in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::rebootReset()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = REBOOT_RESET;
  	commandBuffer.size = 1;
  	numResponseBytes = 0;
   	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    rxDataBlockFast
*Description: Execution of RX_DATA_BLOCK_FAST in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::rxDataBlockFast()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = RX_DATA_BLOCK_FAST;
	commandBuffer.data[1] = (uint8_t)(dataBlock.startAddress & 0xFF);
	commandBuffer.data[2] = (uint8_t)((dataBlock.startAddress >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((dataBlock.startAddress >> 16) & 0xFF);

	for (uint16_t i = 0; i < dataBlock.numOfBytes; i++)
	{
		commandBuffer.data[i + 4] = dataBlock.data[i];
	}
	commandBuffer.size = dataBlock.numOfBytes + 4;
	numResponseBytes = 1;
 	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    rxDataBlock32
*Description: Execution of RX_DATA_BLOCK_32 in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::rxDataBlock32()
{
	DataBuffer commandBuffer;
 	commandBuffer.data[0] = RX_DATA_BLOCK_32;
  	commandBuffer.data[1] = (uint8_t)(dataBlock.startAddress & 0xFF);
	commandBuffer.data[2] = (uint8_t)((dataBlock.startAddress >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((dataBlock.startAddress >> 16) & 0xFF);
	commandBuffer.data[4] = (uint8_t)((dataBlock.startAddress >> 24) & 0xFF);

	for (uint16_t i = 0; i < dataBlock.numOfBytes; i++)
	{
		commandBuffer.data[i + 5] = dataBlock.data[i];
	}
 	commandBuffer.size = 5 + dataBlock.numOfBytes;
  	numResponseBytes = 1;
 	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    rxDataBlock
*Description: Execution of RX_DATA_BLOCK in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::rxDataBlock()
{
	DataBuffer commandBuffer;
 	commandBuffer.data[0] = RX_DATA_BLOCK;
	commandBuffer.data[1] = (uint8_t)(dataBlock.startAddress & 0xFF);
	commandBuffer.data[2] = (uint8_t)((dataBlock.startAddress >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((dataBlock.startAddress >> 16) & 0xFF);
  	for (uint16_t i = 0; i < dataBlock.numOfBytes; i++)
	{
		commandBuffer.data[i + 4] = dataBlock.data[i];
	}
	commandBuffer.size = dataBlock.numOfBytes + 4;
  	numResponseBytes = 1;
	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    rxPassword32
*Description: Execution of RX_PASSWORD_32 in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::rxPassword32()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = RX_PASSWORD_32;
  	for (uint16_t i = 0; i < dataBlock.numOfBytes; i++)
	{
		commandBuffer.data[i + 1] = dataBlock.data[i];
	}
  	commandBuffer.size = 1 + dataBlock.numOfBytes;
  	numResponseBytes = 1;
  	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    rxPassword
*Description: Execution of RX_PASSWORD in P432 family
*Parameters:  none
*Returns:     exception
*******************************************************************************/
DataBuffer P432Target::rxPassword()
{
	DataBuffer commandBuffer;
 	commandBuffer.data[0] = RX_PASSWORD;
 	for (uint16_t i = 0; i < dataBlock.numOfBytes; i++)
	{
		commandBuffer.data[i + 1] = dataBlock.data[i];
	}
  	commandBuffer.size = 1 + dataBlock.numOfBytes;
 	numResponseBytes = 1;
 	return commandBuffer;
}

/*******************************************************************************
*Class:       FramFlash
*Function:    setMemoryOffset
*Description: Execution of SET_MEM_OFFSET in FramFlash family
*Parameters:  none
*Returns:     exception
*******************************************************************************/
DataBuffer P432Target::setMemoryOffset()
{
	throw std::runtime_error("SET_MEMORY_OFFSET command is not available for P432 families...");
}

/*******************************************************************************
*Class:       P432
*Function:    toggleInfo
*Description: Execution of TOGGLE_INFO in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::toggleInfo()
{
	DataBuffer commandBuffer;
 	commandBuffer.data[0] = TOGGLE_INFO;
	commandBuffer.size = 1;
  	numResponseBytes = 1;
   	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    txDataBlock32
*Description: Execution of TX_DATA_BLOCK_32 in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::txDataBlock32(uint16_t size)
{
	DataBuffer commandBuffer;
  	uint32_t addressOffset = offsetBytesRead + address;
  	commandBuffer.data[0] = TX_DATA_BLOCK_32;
	commandBuffer.data[1] = (uint8_t)(addressOffset & 0x000000FF);
	commandBuffer.data[2] = (uint8_t)((addressOffset >> 8) & 0x000000FF);
	commandBuffer.data[3] = (uint8_t)((addressOffset >> 16) & 0x000000FF);
	commandBuffer.data[4] = (uint8_t)((addressOffset >> 24) & 0x000000FF);
	commandBuffer.data[5] = (uint8_t)(size & 0x000000FF);
	commandBuffer.data[6] = (uint8_t)((size >> 8) & 0x000000FF);
 	commandBuffer.size = 7;
  	numResponseBytes = totalBytesReceived;
 	offsetBytesRead += size;
 return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    txDataBlock
*Description: Execution of TX_DATA_BLOCK in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::txDataBlock(uint16_t size)
{
	DataBuffer commandBuffer;
  	uint32_t addressOffset = offsetBytesRead + address;
  	commandBuffer.data[0] = TX_DATA_BLOCK;
	commandBuffer.data[1] = (uint8_t)(addressOffset & 0xFF);
	commandBuffer.data[2] = (uint8_t)((addressOffset >> 8) & 0xFF);
	commandBuffer.data[3] = (uint8_t)((addressOffset >> 16) & 0xFF);
	commandBuffer.data[4] = (uint8_t)(size & 0xFF);
	commandBuffer.data[5] = (uint8_t)((size >> 8) & 0xFF);
	commandBuffer.size = 6;
  	numResponseBytes = totalBytesReceived;
 	offsetBytesRead += size;
 	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    bslVersion32
*Description: Execution of TX_BSL_VERSION_32 in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::bslVersion32()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = TX_BSL_VERSION_32;
 	commandBuffer.size = 1;
  	numResponseBytes = 10;
  	return commandBuffer;
}

/*******************************************************************************
*Class:       P432
*Function:    bslVersion
*Description: Execution of TX_BSL_VERSION in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::bslVersion()
{
	throw std::runtime_error("TX_BSL_VERSION command is not available for P432 Family...");
}

/*******************************************************************************
*Class:       P432
*Function:    txBufferSize
*Description: Execution of TX_BUFFER_SIZE in P432 family
*Parameters:  none
*Returns:     DataBuffer commandBuffer: BSL command to be transmitted
*******************************************************************************/
DataBuffer P432Target::txBufferSize()
{
	DataBuffer commandBuffer;
  	commandBuffer.data[0] = TX_BUFFER_SIZE;
	commandBuffer.size = 1;
  	numResponseBytes = 2;
   	return commandBuffer;
}

/*******************************************************************************
*Class:
*Function:
*Description:
*Parameters:
*Returns:     D
*******************************************************************************/
DataBuffer P432Target::rxSecureDataBlock()
{
	throw std::runtime_error("RX_SECURE_DATA_BLOCK command is not available for P432 Family...");
}

/*******************************************************************************
*Class:       P432
*Function:    initVerbose
*Description: set the verbose mode to off as initialization
*Parameters:  none
*Returns:     none
*******************************************************************************/
void P432Target::initVerbose()
{
	verboseToggle = false;
}

/*******************************************************************************
*Class:       P432
*Function:    verbose
*Description: toggle verbose mode
*Parameters:  none
*Returns:     none
*******************************************************************************/
void P432Target::verbose()
{
	if (verboseToggle == false)
	{
		verboseToggle = true;
	}
	else
	{
		verboseToggle = false;
	}

}

/*******************************************************************************
*Class:       P432
*Function:    retVerbose
*Description: return verbose mode
*Parameters:  none
*Returns:     bool true : verbose on
*             bool false: verbose off
*******************************************************************************/
bool P432Target::retVerbose()
{
	return verboseToggle;
}

/*******************************************************************************
*Class:       P432
*Function:    retNewBaudRate
*Description: return baud rate value
*Parameters:  none
*Returns:     uint32_t newBaudRate : new baud rate value
*******************************************************************************/
uint32_t P432Target::retNewBaudRate()
{
	return newBaudRate;
}

/*******************************************************************************
*Class:       P432
*Function:    retNumResponseBytes
*Description: return number of response byte of respective command
*Parameters:  none
*Returns:     uint32_t numResponseBytes :umber of response byte
*******************************************************************************/
int32_t P432Target::retNumResponseBytes()
{
	return numResponseBytes;
}

/*******************************************************************************
*Class:       P432
*Function:    setDataBlock
*Description: copy DataBlock from streaming input to be applied in BSL command
*Parameters:  DataBlock dataBlockStream: input DataBlock from streaming input
*Returns:     none
*******************************************************************************/
void P432Target::setDataBlock(DataBlock dataBlockStream)
{
	dataBlock = dataBlockStream;
}

/*******************************************************************************
*Class:       FramFlash
*Function:
*Description:
*Parameters:
*Returns:
*******************************************************************************/
uint32_t P432Target::retTxDataBlockSize()
{
	return totalBytesReceived;
}